@@ -1,5 +1,6 @@
 # Python 3.7 support
 from __future__ import annotations
+
 import dataclasses
 import json
 import logging
@@ -12,7 +13,6 @@ from enum import Enum
 from pathlib import Path
 from typing import List, Union, Dict, Optional, OrderedDict as TypeOrderedDict
 
-
 from deprecated import deprecated
 
 from .exceptions import UserException
@@ -66,6 +66,7 @@ class EnvironmentVariables:
     logger_port: str
 
     data_type_support: str
+    project_features: str
 
 
 class SupportedDataTypes(str, Enum):
@@ -203,15 +204,15 @@ class TableMetadata:
         """
         if legacy_manifest:
             final_metadata_list = [{'key': key,
-                                    'value': self.table_metadata[key]}
-                                   for key in self.table_metadata]
+                                    'value': value}
+                                   for key, value in self.table_metadata.items() if value not in [None, '']]
         else:
-            final_metadata_list = [{key: self.table_metadata[key]}
-                                   for key in self.table_metadata]
+            final_metadata_list = {key: value
+                                   for key, value in self.table_metadata.items() if value not in [None, '']}
 
         return final_metadata_list
 
-    @deprecated(version='1.5.1', reason="Please use schema instead of Table Metadata")
+    @deprecated(version='1.5.1', reason="Please use schema instead of Column Metadata")
     def get_column_metadata_for_manifest(self) -> dict:
         """
                 Returns column metadata dict as required by the
@@ -250,13 +251,14 @@ class TableMetadata:
                 final_column_metadata[column] = list()
 
             column_metadata = [{'key': key,
-                                'value': column_metadata_dicts[key]} for key in
-                               column_metadata_dicts]
+                                'value': value} for key, value in
+                               column_metadata_dicts.items() if value not in [None, '']]
             final_column_metadata[column].extend(column_metadata)
 
         return final_column_metadata
 
     @property
+    @deprecated(version='1.5.1', reason="Please use TableDefinition.description instead of TableMetadata")
     def table_description(self) -> str:
         """
         Returns table description (KBC.description)
@@ -401,14 +403,20 @@ class TableMetadata:
                 Args:
 
         """
+        if value is None:
+            return
         self.table_metadata = {**self.table_metadata, **{key: value}}
 
+    @deprecated(version='1.5.1', reason="Column metadata ere moved to dao.TableDefinition.schema property."
+                                        "Please use the dao.ColumnDefinition.metadata")
     def add_column_metadata(self, column: str, key: str, value: Union[str, bool, int], backend="base"):
         """
         Add/Updates column metadata and ensures the Key is unique.
         Args:
 
         """
+        if value is None:
+            return
         if not self.column_metadata.get(column):
             self.column_metadata[column] = dict()
 
@@ -416,6 +424,8 @@ class TableMetadata:
 
         # self.schema = [ColumnDefinition(name=column, data_type={backend: DataType(type=value)})]
 
+    @deprecated(version='1.5.1', reason="Column metadata ere moved to dao.TableDefinition.schema property."
+                                        "Please use the dao.ColumnDefinition.metadata")
     def add_multiple_column_metadata(self, column_metadata: Dict[str, List[dict]]):
         """
         Add key-value pairs to column metadata.
@@ -495,7 +505,6 @@ class ColumnDefinition:
     Represents the definition of a column within a table schema.
 
     Attributes:
-        name (Optional[str]): The name of the column. Defaults to None.
         data_types (Optional[Union[Dict[str, DataType], BaseType]]): Data types of the column for specified backend.
         This can be a specific `DataType` or a `BaseType`, or a dictionary mapping from a string to one of these types.
         Defaults to BaseType.String.
@@ -576,7 +585,7 @@ class SupportedManifestAttributes(SubscriptableDataclass):
                 to_remove = ['primary_key', 'columns', 'distribution_key', 'column_metadata', 'metadata']
                 attributes = list(set(attributes).difference(to_remove))
 
-                to_add = ['manifest_type', 'has_header', 'description', 'table_metadata', 'schema']
+                to_add = ['manifest_type', 'has_header', 'table_metadata', 'schema']
                 attributes.extend(to_add)
 
         elif stage == 'in':
@@ -772,13 +781,14 @@ class TableDefinition(IODefinition):
 
     MANIFEST_ATTRIBUTES = {'in': INPUT_MANIFEST_ATTRIBUTES,
                            'out': OUTPUT_MANIFEST_ATTRIBUTES}
+    SCHEMA_TYPE = Union[Dict[str, ColumnDefinition], TypeOrderedDict[str, ColumnDefinition], List[str]]
 
     def __init__(self, name: str,
                  full_path: Optional[Union[str, None]] = None,
                  is_sliced: Optional[bool] = False,
                  destination: Optional[str] = '',
                  primary_key: Optional[List[str]] = None,
-                 schema: Optional[Union[TypeOrderedDict[str, ColumnDefinition], list[str]]] = None,
+                 schema: SCHEMA_TYPE = None,
                  incremental: Optional[bool] = None,
                  table_metadata: Optional[TableMetadata] = None,
                  enclosure: Optional[str] = '"',
@@ -787,7 +797,11 @@ class TableDefinition(IODefinition):
                  stage: Optional[str] = 'out',
                  write_always: Optional[bool] = False,
                  has_header: Optional[bool] = None,
-                 # input
+                 description: Optional[str] = None,
+
+                 # storage staging
+                 s3: Optional[dict] = None,
+                 abs: Optional[dict] = None,
                  **kwargs
                  ):
         """
@@ -814,6 +828,7 @@ class TableDefinition(IODefinition):
             write_always: Bool: If true, the table will be saved to Storage even when the job execution
                            fails.
             schema: (dict|lis[str]) Mapping of column names andColumnDefinition objects, or a list of names
+            description: str: Table description
 
         """
         super().__init__(full_path)
@@ -823,7 +838,7 @@ class TableDefinition(IODefinition):
         # initialize manifest properties
         self._destination = None
         self.destination = destination
-        self._schema = dict()
+        self._schema: Dict[str, ColumnDefinition] = dict()
 
         if schema:
             self.schema = schema
@@ -844,11 +859,22 @@ class TableDefinition(IODefinition):
         if not table_metadata:
             table_metadata = TableMetadata()
         self.table_metadata = table_metadata
+        if description:
+            self.table_metadata.add_table_description(description)
 
         self.delete_where_values = None
         self.delete_where_column = None
         self.delete_where_operator = None
 
+        if kwargs.get('delete_where_values'):
+            self.delete_where_values = kwargs['delete_where_values']
+
+        if kwargs.get('delete_where_column'):
+            self.delete_where_column = kwargs['delete_where_column']
+
+        if kwargs.get('delete_where_operator'):
+            self.delete_where_operator = kwargs['delete_where_operator']
+
         self.set_delete_where_from_dict(delete_where)
         self.write_always = write_always
 
@@ -867,6 +893,10 @@ class TableDefinition(IODefinition):
         self.stage = stage
         self.has_header = has_header or self._has_header_in_file()
 
+        # storage staging
+        self._s3 = s3
+        self._abs = abs
+
     def __get_stage_inferred(self):
         if self._uri:
             return 'in'
@@ -883,7 +913,9 @@ class TableDefinition(IODefinition):
                                 delimiter: Optional[str] = ',',
                                 delete_where: Optional[dict] = None,
                                 write_always: Optional[bool] = False,
-                                schema: Optional[List[ColumnDefinition]] = None,
+                                schema: SCHEMA_TYPE = None,
+                                description: Optional[str] = None,
+                                **kwargs
                                 ):
         """
         Factory method for creating a TableDefinition instance for output tables.
@@ -903,6 +935,7 @@ class TableDefinition(IODefinition):
             delete_where (Optional[dict]): Criteria for row deletion in incremental loads. Defaults to None.
             write_always (Optional[bool]): If True, the table will be saved to storage even if the job fails.
             schema (Optional[List[ColumnDefinition]]): Dictionary of ColumnDefinition objects.
+            description (Optional[str]): The description of the table. Defaults to None.
 
         Returns:
             TableDefinition: An instance of TableDefinition configured for output tables.
@@ -918,6 +951,8 @@ class TableDefinition(IODefinition):
                    delete_where=delete_where,
                    write_always=write_always,
                    schema=schema,
+                   description=description,
+                   **kwargs
                    )
 
     @classmethod
@@ -935,7 +970,7 @@ class TableDefinition(IODefinition):
                                delete_where: Optional[dict] = None,
                                stage: Optional[str] = 'in',
                                write_always: Optional[bool] = False,
-                               schema: Optional[List[ColumnDefinition]] = None,
+                               schema: Optional[Union[TypeOrderedDict[str, ColumnDefinition], list[str]]] = None,
                                rows_count: Optional[int] = None,
                                data_size_bytes: Optional[int] = None,
                                is_alias: Optional[bool] = False,
@@ -945,7 +980,13 @@ class TableDefinition(IODefinition):
                                id: Optional[str] = '',
                                created: Optional[str] = None,
                                last_change_date: Optional[str] = None,
-                               last_import_date: Optional[str] = None):
+                               last_import_date: Optional[str] = None,
+
+                               # storage staging
+                               s3: Optional[dict] = None,
+                               abs: Optional[dict] = None,
+                               **kwargs
+                               ):
         """
         Factory method for creating a TableDefinition instance for input tables.
 
@@ -975,6 +1016,8 @@ class TableDefinition(IODefinition):
             created (Optional[str]): The creation timestamp of the table. Defaults to None.
             last_change_date (Optional[str]): The last modification timestamp of the table. Defaults to None.
             last_import_date (Optional[str]): The last import timestamp of the table. Defaults to None.
+            s3 (Optional[dict]): A dictionary containing Amazon S3 storage details. Defaults to None.
+            abs (Optional[dict]): A dictionary containing Azure Blob Storage details. Defaults to None.
 
         Returns:
             TableDefinition: An instance of TableDefinition configured for input tables.
@@ -1000,7 +1043,11 @@ class TableDefinition(IODefinition):
                    id=id,
                    created=created,
                    last_change_date=last_change_date,
-                   last_import_date=last_import_date)
+                   last_import_date=last_import_date,
+                   s3=s3,
+                   abs=abs,
+                   **kwargs
+                   )
 
     @classmethod
     def convert_to_column_definition(cls, column_name, column_metadata, primary_key=False):
@@ -1088,6 +1135,9 @@ class TableDefinition(IODefinition):
         else:
             name = Path(manifest_file_path).stem
 
+        if manifest.get('name'):
+            name = manifest.get('name')
+
         # test if the manifest is output and incompatible
         force_legacy_mode = False
         if not manifest.get('columns') and manifest.get('primary_key'):
@@ -1097,28 +1147,61 @@ class TableDefinition(IODefinition):
 
         if manifest.get('id'):
             stage = 'in'
+            table_def = cls.build_input_definition(
+                # helper parameters
+                stage=stage,
+                force_legacy_mode=force_legacy_mode,
+                is_sliced=is_sliced,
+                full_path=full_path,
+
+                # basic in manifest parameters
+                id=manifest.get('id'),
+                uri=manifest.get('uri'),
+                name=name,
+                primary_key=manifest.get('primary_key'),
+                created=manifest.get('created'),
+                last_change_date=manifest.get('last_change_date'),
+                last_import_date=manifest.get('last_import_date'),
+                schema=cls.return_schema_from_manifest(manifest),
+                table_metadata=TableMetadata(manifest),
+
+                # additional in manifest parameters
+                rows_count=manifest.get('rows_count'),
+                data_size_bytes=manifest.get('data_size_bytes'),
+                is_alias=manifest.get('is_alias'),
+                attributes=manifest.get('attributes'),
+                indexed_columns=manifest.get('indexed_columns'),
+
+                # storage staging
+                s3=manifest.get('s3'),
+                abs=manifest.get('abs'),
+            )
+
         else:
             stage = 'out'
+            table_def = cls.build_output_definition(
+                # helper parameters
+                stage=stage,
+                force_legacy_mode=force_legacy_mode,
+                is_sliced=is_sliced,
+                full_path=full_path,
 
-        table_def = cls(name=name,
-                        stage=stage,
-                        full_path=full_path,
-                        is_sliced=is_sliced,
-                        id=manifest.get('id'),
-                        table_metadata=TableMetadata(manifest),
-                        primary_key=manifest.get('primary_key'),
-                        schema=cls.return_schema_from_manifest(manifest),
-                        uri=manifest.get('uri'),
-                        created=manifest.get('created'),
-                        last_change_date=manifest.get('last_change_date'),
-                        last_import_date=manifest.get('last_import_date'),
-                        rows_count=manifest.get('rows_count'),
-                        data_size_bytes=manifest.get('data_size_bytes'),
-                        is_alias=manifest.get('is_alias'),
-                        force_legacy_mode=force_legacy_mode,
-                        indexed_columns=manifest.get('indexed_columns'),
-                        attributes=manifest.get('attributes')
-                        )
+                # basic out manifest parameters
+                name=name,
+                destination=manifest.get('destination'),
+                schema=cls.return_schema_from_manifest(manifest),
+                incremental=manifest.get('incremental', False),
+                primary_key=manifest.get('primary_key'),
+                write_always=manifest.get('write_always', False),
+                delimiter=manifest.get('delimiter', ','),
+                enclosure=manifest.get('enclosure', '"'),
+                table_metadata=TableMetadata(manifest),
+
+                # additional in manifest parameters
+                delete_where_values=manifest.get('delete_where_values'),
+                delete_where_column=manifest.get('delete_where_column'),
+                delete_where_operator=manifest.get('delete_where_operator')
+            )
 
         return table_def
 
@@ -1207,7 +1290,6 @@ class TableDefinition(IODefinition):
             'column_metadata': self.table_metadata._get_legacy_column_metadata_for_manifest(),
             'manifest_type': manifest_type,
             'has_header': self.has_header,
-            'description': None,
             'table_metadata': self.table_metadata.get_table_metadata_for_manifest(),
             'delete_where_column': self.delete_where_column,
             'delete_where_values': self.delete_where_values,
@@ -1215,7 +1297,8 @@ class TableDefinition(IODefinition):
             'schema': [col.to_dict(name)
                        for name, col in self.schema.items()] if isinstance(self.schema, (OrderedDict, dict)) else []
         }
-        if legacy_manifest:
+
+        if (legacy_manifest and not self.has_header) or self.stage == 'in':
             fields['columns'] = self.column_names
 
         new_dict = fields.copy()
@@ -1339,8 +1422,8 @@ class TableDefinition(IODefinition):
 
     @incremental.setter
     def incremental(self, incremental: bool):
-        if incremental:
-            self._incremental = True
+        if incremental is not None:
+            self._incremental = incremental
 
     @property
     def write_always(self) -> bool:
@@ -1907,7 +1990,8 @@ class TableInputMapping(SubscriptableDataclass):
     full_path: str = None
     where_operator: str = ''
     days: int = 0
-    column_types: List[TableColumnTypes] = None
+    column_types: List[TableColumnTypes] = None,
+    file_type: str = "csv"
 
 
 @dataclass
