@@ -18,7 +18,7 @@ from pygelf import GelfUdpHandler, GelfTcpHandler
 from pytz import utc
 
 from . import dao
-from .dao import ColumnDefinition
+from .dao import ColumnDefinition, TableDefinition
 from .exceptions import UserException
 
 
@@ -55,7 +55,8 @@ def init_environment_variables() -> dao.EnvironmentVariables:
                                     real_user=os.environ.get('KBC_REALUSER', None),
                                     logger_addr=os.environ.get('KBC_LOGGER_ADDR', None),
                                     logger_port=os.environ.get('KBC_LOGGER_PORT', None),
-                                    data_type_support=os.environ.get('KBC_DATA_TYPE_SUPPORT', None)
+                                    data_type_support=os.environ.get('KBC_DATA_TYPE_SUPPORT', None),
+                                    project_features=os.environ.get('KBC_PROJECT_FEATURE_GATES', '')
                                     )
 
 
@@ -133,10 +134,14 @@ class CommonInterface:
         args, unknown = argparser.parse_known_args()
         data_folder_path = args.data_dir
 
-        if data_folder_path == '' and self.environment_variables.data_dir:
-            data_folder_path = self.environment_variables.data_dir
-        elif data_folder_path == '':
-            data_folder_path = '/data/'
+        if not data_folder_path:
+            cwd = Path(os.getcwd())
+            if self.environment_variables.data_dir:
+                data_folder_path = self.environment_variables.data_dir
+            elif cwd.resolve().joinpath('data').is_dir():
+                data_folder_path = cwd.resolve().joinpath('data').as_posix()
+            elif cwd.resolve().parent.joinpath('data').is_dir():
+                data_folder_path = cwd.resolve().parent.joinpath('data').as_posix()
 
         return data_folder_path
 
@@ -337,7 +342,8 @@ class CommonInterface:
                                  write_always: bool = False,
                                  schema: Union[
                                      OrderedDict[str, ColumnDefinition], list[str]] = None,
-                                 has_header: Optional[bool] = None) -> dao.TableDefinition:
+                                 has_header: Optional[bool] = None,
+                                 description: Optional[str] = None) -> dao.TableDefinition:
         """
                 Helper method for dao.TableDefinition creation along with the "manifest".
                 It initializes path according to the storage_stage type.
@@ -380,6 +386,7 @@ class CommonInterface:
                                    primary_key=primary_key,
                                    columns=columns,
                                    incremental=incremental,
+                                   description=description,
                                    table_metadata=table_metadata,
                                    enclosure=enclosure,
                                    delimiter=delimiter,
@@ -426,13 +433,11 @@ class CommonInterface:
                                              delete_where=delete_where,
                                              schema=schema)
 
-    SCHEMA_TYPE = Union[Dict[str, ColumnDefinition], OrderedDict[str, ColumnDefinition], List[str]]
-
     def create_out_table_definition(self, name: str,
                                     is_sliced: bool = False,
                                     destination: str = '',
                                     primary_key: List[str] = None,
-                                    schema: SCHEMA_TYPE = None,
+                                    schema: TableDefinition.SCHEMA_TYPE = None,
                                     incremental: bool = None,
                                     table_metadata: dao.TableMetadata = None,
                                     enclosure: str = '"',
@@ -440,6 +445,7 @@ class CommonInterface:
                                     delete_where: dict = None,
                                     write_always: bool = False,
                                     has_header: Optional[bool] = None,
+                                    description: Optional[str] = None,
                                     **kwargs
                                     ) -> dao.TableDefinition:
         """
@@ -463,6 +469,7 @@ class CommonInterface:
                            fails.
                            has_header:Optional[bool] = flag whether the header is present in the file,
                                 if None legacy method is used
+                           description: Table description
         """
 
         return self._create_table_definition(name=name,
@@ -478,7 +485,8 @@ class CommonInterface:
                                              delete_where=delete_where,
                                              write_always=write_always,
                                              schema=schema,
-                                             has_header=has_header)
+                                             has_header=has_header,
+                                             description=description)
 
     # # File processing
 
@@ -902,6 +910,10 @@ class CommonInterface:
     def files_in_path(self):
         return os.path.join(self.data_folder_path, 'in', 'files')
 
+    @property
+    def _running_in_kbc(self):
+        return self.environment_variables.stack_id or False
+
     @property
     def is_legacy_queue(self) -> bool:
         """
@@ -909,9 +921,10 @@ class CommonInterface:
         Returns:
 
         """
-        features = os.environ.get('KBC_PROJECT_FEATURE_GATES')
+        features = self.environment_variables.project_features
+
         is_legacy_queue = True
-        if not features or 'queuev2' in features:
+        if not self._running_in_kbc or 'queuev2' in features:
             is_legacy_queue = False
         return is_legacy_queue
 
@@ -950,7 +963,6 @@ class CommonInterface:
         """
 
         if not legacy_manifest:
-
             legacy_manifest = self._expects_legacy_manifest()
 
         manifest = io_definition.get_manifest_dictionary(legacy_queue=self.is_legacy_queue,
@@ -961,7 +973,9 @@ class CommonInterface:
             json.dump(manifest, manifest_file)
 
     def _expects_legacy_manifest(self) -> bool:
-        legacy_manifest = self.environment_variables.data_type_support not in ('authoritative', 'hints')
+        legacy_manifest = \
+            (self._running_in_kbc and self.environment_variables.data_type_support not in ('authoritative', 'hints'))
+
         om_override = self.configuration.config_data.get('storage', {}).get('output', {}).get('data_type_support')
         if om_override:
             legacy_manifest = om_override not in ('authoritative', 'hints')
@@ -1181,7 +1195,7 @@ class Configuration:
         Returns: List[FileInputMapping]
 
         """
-        defs = self.config_data.get('storage', {}).get('output', {}).get('files', [])
+        defs = self.config_data.get('storage', {}).get('input', {}).get('files', [])
         files = []
         for file in defs:
             om = dao.build_dataclass_from_dict(dao.FileInputMapping, file)
